(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     28929,        731]
NotebookOptionsPosition[     27333,        672]
NotebookOutlinePosition[     27762,        689]
CellTagsIndexPosition[     27719,        686]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["The VC package", "Subsection"],

Cell[TextData[{
 "Estimation procedure by Ekkehart Schlicht (University of Munich). \
Implemented by Johannes Ludsteck (Institute for Employment Research \
Nuremberg) for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " ",
 StyleBox["5.0",
  FontSlant->"Italic"],
 ". and adapted to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " ",
 StyleBox["8",
  FontSlant->"Italic"],
 ".\n\nVC is a method-of-moments estimation procedure for linear time series \
models with time-varying (random walk) coefficients, developed by Ekkehart \
Schlicht (University of Munich).\n\nConsider the model\n",
 Cell[BoxData[{
  RowBox[{
   SubscriptBox["y", "t"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "t"], 
     SubscriptBox["x", "t"]}], "+", 
    SubscriptBox["u", "t"]}]}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"where", " ", 
     SubscriptBox["a", "t"], "and", " ", 
     SubscriptBox["x", "t"], "is", " ", "are"}], "-", "vectors"}], ",", 
   RowBox[{
    SubscriptBox["u", "t"], "follows", " ", "a", " ", "normal", " ", 
    "distribution", " ", "and", " ", 
    SubscriptBox["a", "t"], "is", " ", "generated", " ", "by", " ", "a", " ", 
    "random", " ", "walk", " ", "process", " ", "of", " ", "the", " ", 
    "form"}]}], "\n", 
  RowBox[{
   SubscriptBox["a", "t"], "=", 
   RowBox[{
    SubscriptBox["a", 
     RowBox[{"t", "-", "1"}]], "+", 
    SubscriptBox["v", "t"]}]}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"where", " ", 
     SubscriptBox["v", "t"], "follows", " ", "a", " ", "multivariate", " ", 
     "normal", " ", "distribution", " ", "with", " ", "mean", " ", "0", " ", 
     "and", " ", "variance"}], "-", 
    RowBox[{"covariance", " ", "matrix", " ", "\[Sum]"}]}], "=", 
   RowBox[{"diag", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["\[Sigma]", "1", "2"], ",", "...", ",", 
       SubsuperscriptBox["\[Sigma]", "n", "2"]}], ")"}], "."}]}]}]}], "Text",
  FontFamily->"Times"],
 "\nIt is routine to estimate such models by Maximum Likelihood using the \
Kalman filter.  However, for short time series, maximum likelihood estimation \
produces corner solutions (",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Sigma]", "i", "2"], TraditionalForm]]],
 "=0) in many cases, even if the true variances are strictly positive. VC \
does better in many cases."
}], "Text",
 CellChangeTimes->{{3.7527248755097656`*^9, 3.7527249651660156`*^9}, 
   3.7531659571875*^9},
 FontSize->14],

Cell[CellGroupData[{

Cell["This loads the package", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "VCM8`"}]}], "Input",
 CellChangeTimes->{{3.75290651533631*^9, 3.752906541694605*^9}, {
  3.752906713631711*^9, 3.752906713913506*^9}}],

Cell["\<\
Two further helper functions. VCModel generates simulated data for a linear \
time series model with varying coefficients.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"VCModel", "[", 
     RowBox[{"t_", ",", 
      RowBox[{"Sigma_", "?", "MatrixQ"}], ",", 
      RowBox[{"bv_", "?", "VectorQ"}], ",", "uv_", ",", "opts___"}], "]"}], ":=",
     "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"n", "=", 
         RowBox[{"Length", "[", "bv", "]"}]}], ",", "mndist", ",", "brand", 
        ",", "urand", ",", "b", ",", "x", ",", "y", ",", "bMat"}], "}"}], ",",
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"mndist", "=", 
        RowBox[{"MultinormalDistribution", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0.0", ",", 
            RowBox[{"{", 
             RowBox[{"n", "-", "1"}], "}"}]}], "]"}], ",", "Sigma"}], "]"}]}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"brand", ":=", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Random", "[", 
            RowBox[{"NormalDistribution", "[", 
             RowBox[{"0.0", ",", "#"}], "]"}], "]"}], "&"}], ",", 
          RowBox[{"Sqrt", "[", "bv", "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"urand", ":=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{"0.0", ",", 
            RowBox[{"Sqrt", "[", "uv", "]"}]}], "]"}], ",", "t"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"x", "=", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"{", "1.0", "}"}], ",", "#"}], "]"}], "&"}], ",", 
          RowBox[{"RandomVariate", "[", 
           RowBox[{"mndist", ",", "t"}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"b", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"bMat", "=", 
          RowBox[{"NestList", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#1", "+", "brand"}], "&"}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{"1.0", ",", 
              RowBox[{"{", "n", "}"}]}], "]"}], ",", 
            RowBox[{"t", "-", "1"}]}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"y", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"X", "[", "x", "]"}], ".", "b"}], "+", "urand"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"y", ",", "x", ",", 
         RowBox[{"Transpose", "[", "bMat", "]"}]}], "}"}]}]}], "]"}]}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "x_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", ",", "n"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "n"}], "}"}], "=", 
       RowBox[{"Dimensions", "[", "x", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"SparseArray", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"i", "-", "1"}], ")"}], " ", "n"}], "<", "j", 
           "\[LessEqual]", 
           RowBox[{"i", " ", "n"}]}]}], "\[RuleDelayed]", 
         RowBox[{"x", "\[LeftDoubleBracket]", 
          RowBox[{"i", ",", 
           RowBox[{"j", "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"i", "-", "1"}], ")"}], " ", "n"}]}]}], 
          "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", 
          RowBox[{"t", " ", "n"}]}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7506561009091797`*^9, 3.7506561198154297`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here we set the parameters of the model and generate the data\
\>", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SeedRandom", "[", "123", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S", "=", 
   RowBox[{"5", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.5", ",", "1"}], "}"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bv", "=", 
   RowBox[{"{", 
    RowBox[{"0.05", ",", "0.1", ",", "0.15"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"y", ",", "x", ",", "b"}], "}"}], "=", 
   RowBox[{"VCModel", "[", 
    RowBox[{"t", ",", "S", ",", "bv", ",", "1.0"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7506720267304688`*^9, 3.7506720371679688`*^9}, {
   3.7507479193222656`*^9, 3.7507479208535156`*^9}, 3.7508618000322266`*^9, {
   3.7527241959541016`*^9, 3.7527242137041016`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["This is a plot of the time paths of the three coefficients", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotseries", "=", 
  RowBox[{"GraphicsGrid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ListPlot", "[", 
        RowBox[{"#1", ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"DisplayFunction", "\[Rule]", "Identity"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", "200"}]}], "]"}], "&"}], ")"}], "/@",
      "b"}], "}"}], "]"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], "]"}], 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.7506577606416016`*^9, 3.7506578022978516`*^9}, {
  3.7506579114228516`*^9, 3.7506579194384766`*^9}, {3.7506579938603516`*^9, 
  3.7506580498447266`*^9}, {3.7506580803134766`*^9, 3.7506580886728516`*^9}, {
  3.7509222985791016`*^9, 3.7509223040791016`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQEf7FFpBoe2ktdXrWY/hvI5HDJOT/0RyvIQyhdw
WHCkQ1Ne+ziUL+KQqs7eoxJ0BsqXcNh7NiZFufEclC/j4FS7bNstxwdQvoLD
+6Mv3FjVn0H5Sg7ujyeoGES8hPJVHIRem/7PmANzj5rDHpYf2V+DPkH5Gg5r
fwYvueIMk9dyUDV5/eM532soX8dhau0uHhkjmHl6Dm8Yz/fyub+A8g0cNj3Y
z6Nm8gbKN3Tw5mfy/ugBU2/k8GDmZMuMpTC+sUNkeeTECf2foXwTh1V301st
Nb9A+aYO7txdp+TZYPJmDlIFnz1WWMHkzR16zCd6FT7/BuVbODg2urstj4P5
x9LhAtPFzZ3hMPVWDrJPG69ODIeZZ+3wT7jsf5MCTN7GoUnwsGtg+Uco39bh
QF1lzr8omHo7hykLz59ZEALj2zs8iOTdner7Fcp3cGie8EuzfyPU/gYHB8Ud
d6fd6YWZ5+hwZ8Pau9eewOQdHTauiGDZtgEWvk4OKea8yS9LoeobnBwmL4tU
034Aiw9nBw0j/+hufmj4NTg7TDym9iDPEqbfxaF7zparNjuh/AYXB7s9amrC
X2Hyrg5Pbll3SGo/h8q7OqyeFndk4m9YenFzCJ45PWWK122ovJtDzdSUvXv/
XITKuzuEMD/f/IDnBFTe3WEO2+yvLku274fIezisu+rTr2p5ECrv4dAjqxRW
sX0hVL+ng/eMdZnr0hfbAwD3HOeC
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      ImageSize->200,
      PlotRange->{{0., 50.}, {-0.09235030170659758, 1.4315045273574212`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {107.5, -64.89356881873896}, 
     ImageScaled[{0.5, 0.5}], {200, 123.60679774997895`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxV0F1I01EYx/F/M2ORlFpDzTacycg5S63lepn+ppsa4pJgFrswXMS6CGc1
TRaZUquLfKGwN4cp6Jp4E1KWhbiYUYaEGGlqLelCZumcpBO3OazY87/owOHh
w5cDh0eoM5w4y2EYJuPv/TdDZzH7/8lgIFCfyR/8TeZCVlQfb7zrJkfitXNk
TmXwkHdgtHQ2eCuL7bHgrK/oXPYZ8i4wN+Xd3aY5cgKafZvsVy5/ICei74vG
JdHfs4echBJ11Gdt4SR1EX6ZtGnzahd5DyKuXZRK9UtkMeIdWJ8aZC1BS6/X
8vYd673wP61caPL7yGnoTZYtpftXyekoapYUj+gYhJwBZdzOeUvhGvX9WD4Z
XW4OC5IP4FWgwysVrpClGPCNeUarl8kH4a6zVnwSsT0T58Mb7TeS2f3KcHWf
+r2ggd3vIVQaTbxSp5d8GNoLnnHrTIB8BDUxl2IEKg797yjOLRhtThtrOare
zCqEH9n/Z6G/6fZPWWoYORucHvmp8pGNZOD4Ytl46zN6Xwt4f2we1reFU1eg
v2rs69QkuVYBR1LQUO1mew4e8b91PRRwqedAeF2h0XSRmVxoVrnioSG256Jz
LVzZbt5CXQltirRT3hZJXYmUmjOxfTYyo4Kk7uWTad5W6ir4NgzHPX5OZvIQ
lVXxvawlgnoe/I0PJgQvtlHPR+LunpL7d6Kp54MvsnYIU8lMASQT5mmLYzv1
AjT4/IHTOWTmGBKK/a1iCw9/ABll3PA=
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      ImageSize->200,
      PlotRange->{{0., 50.}, {-0.020901395434939934`, 5.401529758837597}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {322.5, -64.89356881873896}, 
     ImageScaled[{0.5, 0.5}], {200, 123.60679774997895`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxV0mtIU2Ecx/HjsmXExGBakWCOmq6ruWnZTH9zF6drJAtMrDezKbEEoRZp
mAxRNAIrqmHZq6CkCUPUijVhpS0rzHSNXSDRclS01EFLcI11Yf/zogMPDx++
8Jzn/DnZdU26eg7DMPl/17898YRL/98ZxH9/tRbEP5JT4HLUdBb3e8lpSCq8
/tzZNUnmo72hr7ouye1MeDPmrS4RPPepZyLmqDmzcGyS+jZkWm2p53OeUBeg
KlcdrQp4qW8H90KowvdhniyELvlI8eJPPzkX0VnNvY1aD3knIpyWl+lHX5B3
g7O2Y49G9568F+fyLPX2i+/IeehaccRbri2S96N2asPjNsEPcj4qH8bEqkvf
yWI89Ynipp5lsgR9sVtauYt1AZYzFGoTN0QuRPBmh0O5vEA+gKVKCZfrnyUf
hKzudEaqeI5cBL7Bcocn9JEP4e4vpz/J/YUsxbRHmib0fiIXI6K09TcvfSYf
RuNUt2HiKttL4BadNQousy6FzWucG3/EzhOobmrL3pITTtgMpDSPzmzqJTMy
DIpPSgOqN9Rl4MXmBWvG2fPKsLVz/YNIUZB6GUqZ9BOhHez85Gjg28d8tavU
5bBLDBLHDbYrMBAe2xccpvmaFdAN9QqLsr5RV2LU8EprbHxLXQnebYFsdYR9
vwou/WuNfpi+36yCYaD7eLaJvX85GH2WuTV5hXo5Znjt8V1XyIwaJRO+Z4pT
UepqtPZ0T/cE2P+hAiODbss6b9D5Bz7p/CU=
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      ImageSize->200,
      PlotRange->{{0., 50.}, {-1.6492354901242403`, 1.}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {537.5, -64.89356881873896}, 
     ImageScaled[{0.5, 0.5}], {200, 123.60679774997895`}]}, {}},
  ContentSelectable->True,
  ImageSize->{657., 141.7871376374779},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.7506580507666016`*^9, {3.7506580823291016`*^9, 3.7506580895634766`*^9}, 
   3.7506720853085938`*^9, 3.7507479291191406`*^9, 3.750748065908203*^9, 
   3.7508615995947266`*^9, 3.7508618112978516`*^9, 3.7508704811875*^9, 
   3.750870558703125*^9, {3.7509221827666016`*^9, 3.7509222072822266`*^9}, 
   3.7509223055947266`*^9, {3.7527242556572266`*^9, 3.7527242732822266`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The next cell contains a call to VCEstimate. VCEstimate returns a List \
containing [1] a matrix with the time paths of the coefficients bhat, [2] a \
matrix with the respective standard errors sdb, [3] the standard error of the \
residual sdu, and [4] the vector of standard errors of the random walk \
residuals sdi. Since the computation of the estimates may be time-consuming \
for lage models, the estimation process is reported\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"bhat", ",", "sdb", ",", "sdu", ",", "sdi"}], "}"}], "=", 
   RowBox[{"VCEstimate", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}], ";"}]], "Input"],

Cell["\<\
Iteration: 59 Objective function value: -240.2201745
Variance Ratios: {0.63122, 0.739561, 0.336244}\
\>", "Output"]
}, Open  ]],

Cell["\<\
The cell above serves as an iteration monitor. It prints the number of \
completed iterations, the actual value of the  convergence criterion and the \
actual value of variance ratios (=sdi/sdu). The convergence criterion used to \
compute the estimator is the maximum of relative changes of the variance \
ratios between two successive steps of the fixed point iteration.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
CIPlot is a helper function which allows to plot the coefficients together \
with confidence interval bands (default option is 0.95 percent bands).\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "CIPlot", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"CILevel", "\[Rule]", "0.95`"}], ",", 
   RowBox[{"RegressorNames", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "200"}], ",", 
   RowBox[{"Columns", "\[Rule]", "2"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7507479484316406`*^9, 3.7508616170634766`*^9, 
  3.752724306892578*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7508619406572266`*^9, 3.7508619463291016`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CIPlot", "[", 
  RowBox[{"bhat", ",", "sdb", ",", 
   RowBox[{"Columns", "\[Rule]", "3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7509222789072266`*^9, 3.7509222853134766`*^9}, {
  3.752724318564453*^9, 3.752724330033203*^9}, {3.752724411330078*^9, 
  3.752724433001953*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQEf7Lcms08RPPfRHirgYHOiWz+u+BOUz+EgF290
lOPieyhfwOG/lgm3efJbKF/EIfrKh0fvOl9A+RIOn54/vZfz9x6UL+PwLv5I
gOivS1C+gkO6nWvqrfYjUL6SA+eNA7qahcehfBUH/YgHv5n8r0P5ag4rrkd6
7L/8EMrXcFBY3vXH2/QVlK/lMF1B2buc7w2Ur+MwY06aRWIgzL16Dt9NlWd6
OcL8Y+DAEXG098+571C+ocMOB4kZPmv/QPlGDuXKvB7Fhr+hfGOHIxFPL62W
+A/lmzh8KKzZcmnPXyjf1MHzS9guIXGYejOH0Eiz5NN6MPPNHTZ5ytd8OP0Z
yrdwCPMtFTOogYW3pYP9tbB4xQ8w91o5vD6zWSTCAOYfawe2Yi+BPwqw8LZx
OOSbrxGf/wHKt3U4I3awRIIR5j87h979pcaXmmD22TtwPdCQDrb5AuU7OKR8
/re9dDJUvsHB4dnFui3/L8DUOzpYVinw3L0MVd/g6MCkNEXr0Q6YficH11+y
Qby7YfJODnF3tVa1ToPJOzs0zephuZ74DSrv7FD/pld8zoqvUHkXh8Ptc1n4
GqH+aXBxaOs49YC/7Q5U3tWheP/h6abzNkPlXR06mR7+MbTYvB8i7+Yg9r5h
9sw9+yD8BjcHW/Olex//nAXV7+7QEFpleKFtC1S/u4Oa792XSadh8h4O64Tb
F/CZNUHlPRy6Z9xyi9h4ACrv6aBpuKlgn/45ewD75OhV
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.02, 0.02}], LineBox[CompressedData["
1:eJw10mtIk1Ecx/Ens5haOMvBoCJnMsfwlrVKm+43d9HohbcSGUUQicqqKRn0
SpeNoqYhXgiLmNWS0QTXZVZDFEJIXZpzMLtu6daapjjsZgmjYv89cHj4nO//
xTlweCc1ZVVRDMNk/1v//+EvKNGm3Y3PiXoyTBvIstfWGCtfS8JkweKBau3C
HTIbddMZyWd0j2g+EQJ9sMHVaSdzsUPf2hSnmiVvx1LJt6b5cT85CYPqtQ21
oQA5GdPK+faWqgVyCnrVFhHnlI/Mh+tjm17VOEMWgNF0y/XiZjqPEHWG5c2Z
USbqaWC4J4z1vCxyBhivwfPU20PzWdBZpFO5xW/Iu+FSPKw+6/STs9FYvvpY
OBTxHowE7l1OLV4h74W/xQZxTJAsQvnbrm2xTIC8D8p8kX/x0ifyflTwr//a
pHGSD6DtdrtBfeMFOQfM8R+t9rR+ci4sY6JdNa/u0/kPoqdCz6+3dpLFCFyM
39pnHqD5PDQM9S4ZZyfJ+aj8+aDLwXKTJeBf0TGSdTNkgPVu0tKqmgpbC4xW
b7m50eSgLkViwkSoNP09dSl8arPXLPBQL0BZtNcae5SsLcAzm2JCxJ6jLgPX
1Lwq5vioy3BsoDlm6DCZkaNtZ9+1cauJuhwp3+OEPLOb7qfAmDPaKCyh96BV
ILWjv3Qk4St1JcZiOEfYVyNdiTm3IMk0GHkvhTidmef98Psz9ULYn690L1i/
UC+CI32if/2fRepFOP9ytCP2Fpk5hJCMZTOeWx7+C6BA8VE=
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.02, 0.02}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQEf7CVLW2KU85gcoAIOndqsLy/XMkD5HA4KEQmv
HFz/20P4Ag5qEuF3a7v/QfkiDgee9m3s/PMbypdw6Nhpqb9H+weUL+OQdyM6
o/7RFyhfwaGC1V9Ge+FHKF/JIfvmkykC/J+hfBWH14knJHpufoXy1Rzk+O1e
h27+DuVrODiVMD67JPALytdymDR30uGOc3+gfB2HrkcN/slBMPfqOWRvW7Jz
919GqH8MHH4o7jUWPcoC5Rs6OL3X/lfwgw3KN3KYwcc/+0UjK5Rv7JCUMplf
4iOMb+JQqy0/xWQHjG/q8KW20FhAHMY3czjCuVLzAi8zlG/u8LxF9y5fHMx+
C4da5ZqYnUGw8LV0CNd+zrT7Gyw8rRwsqs+G7r4H84+1Q8KCJ1cuFv+F8m0c
0hav7WcugfnP1uHpqmeq/4Rg5tk5tBxsYCxohsnbO6j6S1hrx8Dsd3BQlnjK
qNIB5Tc4OLxtsXn4bzZM3tFB7IbbGaM8mLyjQ9sWuXVnLsPMd3LYPTPxd/YF
KL/ByWFD3k2zCrj9zg41H7KPtcPsa3B2eGGnO3XNVJi8i8MxNY8N8buh/mtw
cfBxfGF14S0svl0dlh7+yrnD/D1U3tWhNaj80nbnZ1B5NwfmcyZvX958BJV3
cwgzYo5xy4HJuzucOTL7/QTp11B5d4e5fRNOLEh6CZX3cMhPu6iypfstVN7D
4S7n7OjblZ+g8p4OnusMfh50/W4PAICV2t4=
          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotLabel->FormBox["\"Coeff. 1\"", TraditionalForm],
      PlotRange->{{0., 50.}, {-0.12006530806041513`, 1.9435232389565025`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {193.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw10WtIU3EYx/GVLpe54UyXLwSbeUMqPV427/vt5ha9iUGFKKMaCQ1Zxd7o
KljSHQKtpLKxpimGoN0slkIZsi5aCKmoBRpBrU1WLppmum7s+f/hcPicL5yH
h7/0wGHDwbU8Hi//3/P/HTkLisF6l+dr8IeCPmDSMWi7vmGJLIBr5e7OW8ZF
cjzKsgvBWRbIiTCdDYZfpDInI6ttNPRbHCCnIGPJP3Ctb5q8GSUO7/JqXjc5
DWeSTpgr24aeRpwOfaPx/vrct9QzUe3603puxkvOhtX4zhpvYvNycKXZa4vr
CZG3wpz0SnLK/Iu8HVHjZblLP8PkPOx33qhrtrN9OXzImTr2ZMBHzkfMolx9
sz1ILsCjkFTs38JcCG1Y2GII+MlFmLigCySsfCLLEO2cf367mv1PDu5ZR+/J
SeZiuGVx65brvpNLEPultsboZi5FzUtLx1yAzSuDzCpyzznYfZRDMtV6sVbO
9qvAG1N3epqW7VeJy53998pLeYhYgX7ZpRHd6BoykO4bmt/bGxWxHfCICrjV
3mjqSjT1DWdwPWS7EuezW/gL03zqKnQVaQyDXAx1FQ7deT8jGBdQV0O4+1vs
vrFY6mrsOho8Ljwioq5BiobfOKeMp65B+1ixPzVTTF0Ln+JxQpOfdS3qnXt0
GinrVThteDisesB6FRpmOz92VbGuw8SmBvmsm2zXwTJSflWUtZG6HhXbhGNN
rxOp65Fs/WwWOJKo70Cqx6C2NUvwF/hs3c8=
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.02, 0.02}], LineBox[CompressedData["
1:eJw10GtIU2Ecx/HDiibWTNGG1TKTOWLNS7NWlm2/zXsR6MIRbZSbKC2wSfXG
QtsbrZVhGpUzSQl7tcZmJDVQtClFwZory3AU3pq1xGSZJY5u7H8eOBw+5/vw
nD/PNoNJXclhGEb67/n/jqwFxWulwyjmzSjoA44UpTlbqwPkKIRLC1y48Y0c
i6rJdZdbjOz+BITs9sbvP0fJidCkzS/1zI+QBbjq6evnZL4ZiDgZJx2aCo16
lpyC2g1Jt1ZuT5KFqM+abh4p85FF0FW7V9/0eei87TCrUurO64bIYiTIEpYT
xX6yBJbAL13S3BdyOrrXSz6cPrNEzkR7e/KgvHGavBOZJpe0d76H/idFbFwL
w/W5qGchSsc1bJ18St4F81jD8ShfJ3k3pnJzjh7Ss/PJwEeJs/egj7wHbQKF
uuPle/JeOEUPh/oefyJno+bRcOqd1gnyPgijrbJxEXuf+1F+7kJNOImdNweD
HaUXT/E/kw8g5q5p7PeTEFkOjuDrlWtZrBUYcE/YBcIfZKDJZbN0W8IRm4E+
+bOVCscf6kokGhht6ASDSFdio9W4kH2dEzGjQnF4syx1dhV1FdIDTYf1Yrbn
YsuOtrcNJWzPxVSzSlsXz6Wehwad/4U/Ppp6HoaFMyOLGTHU89GlCGpqPWup
52P5lUNr4/GoF8DteXDJHGR7AazHmLlxL5kpxEebd5FfTvvNhehcU+bV18dS
L8LoWX59/7s46kWoqnyeIQmSmWJsun9vfDAQh78xRd7G
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.02, 0.02}], LineBox[CompressedData["
1:eJw1z2tI01EYx/Htr+ZMM3OKplazLU2xaG6lrdx+zk2n4DLBqBVZ0YVI/Rdk
KImaRERkUTNJojeaiy7I8I0LI11RdAFHE7NVki90XajmZRs5Uyt8zoHD4XO+
58V5kg/xpUc4gUCQ+W//PxfXhKY5+/guw8iChi7QX2QdUJ4UYpEiaAeeqCzT
f6hH4dnng4/b7vrJMSjqyEowC2fJ8XBGRtWUvvtNToKvayyiWDpJlmCi3cyd
yf5OXouK2D677YaTLEOouCQw6WI9BV2lx3xla7zk9Wg9HXXzmmmenA5n2PO9
r3Qc/TcDLz9eaqjzBJE3Qv6ms7+vj/VNqPakVArVbF45Bu2c454rQM5EfaUi
PG5QQO8V8DcIE9+HMCvxZdzMR1ax95uxm0PTN+MUeQvmm4dNs0t85CyEB6Lb
PrRPk7MRb9LcF0/NkLfiU/WwlE+dI6uwwZjVI3Ky+bZhdavnlmSI/X873Lz9
p10eTM7BixaPrf0rm1eNdb3Tt7tNoWQNRBFK9bngMDLQ5HtwfSSW3AhkzDcd
zj/Pei5+BC5M8F4R9VzM9NgSLMmsayHkK6p21i2lrsWdmvSj1rPLqeehXiOV
rEpdQT0P5WklDqM7mroOflfSsre1Yuo6jF5eOKFXkgV6cAfmagt+sa7HvrKh
0e5e1vORpm7J059iPR8dVwt37O+MoV6AR3sueq12cmMBcq7IynsdsdQNsLiD
JIancdQNeN0YYhkrXkm9ELJx7qFClYi/lbzVCg==
          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotLabel->FormBox["\"Coeff. 2\"", TraditionalForm],
      PlotRange->{{0., 50.}, {-0.1297071475948252, 5.641091396262055}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {580.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQEf7F9NmT+LMaB0P1TAoWLTV5HycxPtIVwOB3eV
/g1S1TC+gMPf9z7/KlzmQ9WLOEg837KKtWcflC/hcHX/BIGG+NVQvozDpj3y
J1pqLkD5Cg68b/fwtP64DuUrObif2CRhtOQmlK/ikFmfoVMpdBvKV3MI9Oxi
W/H5FpSv4ZC6uUUzzxPG13JIKJ0r9uwmTL2Owx+XT9cvMt+A8vUcgM431TsB
4xs4eNamVIlrP4LyDR2OO+foHl32DMo3cjj8W6LgMvclKN/YoYg5dE7TQZh7
TRySD7Md3f70DpRv6pDBPoWL/dE9KN/MYY5gfujd2/ehfHMHBtWyY7mfH0D5
Fg5OVkKTJvXB+JYORlWr/67JgrnHyoH70mJ1m5tPoHxrh2spBYwJMx5C+TYO
hmnPbWJyYOptHb5l/i9MzIXx7RyaCz7nmObD+PYOS/UYKgx9YXwHB935ktId
r6D+bXBwuPNj2WqxLa+g8o4OxvPmF3mUvYfKOzp8UO5wdQ/4BJV3cjD9aaop
de8LVN7JIfu86PbfUd+h8s4OExiCIp50/4DKOztITXY+qS4EVc/g4rBZ1JK/
z/sjVN7FIfSQi+QJZZj9rg4yL25d/LLwMVTe1UGJaQPDn40voPJuDj/WqIeU
fXkLlXdzUPvVFa/yCWoeg7vDZeWyq8/cvkLl3R1cnqbNFaqB8hk8HFbcO+Jq
VA+T93C48d7pGuccmH5Ph8v3Dp/9l/9qPwBh8P96
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.02, 0.02}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQEf7OtUg/xv3f+0HyrgsD3wQi5LyAcon8NhlVFf
ZnjlayhfwEF0vt4Fg8XPoXwRh1RxJZNquydQvoSDhpuDXtLWh1C+jINl1fYT
FqteQfkKDvKr6+QYtGHmKzn8kL/Fsv4SjK/i0Nb/yyvqyTsoX81hi9TC2pub
YPIaDjLXlcv3dr+H8rUcpBWsQ22sXkD5Og4ev98WVbvC7NNzOPRhR714O0y/
gcMDX86ymN+foXxDh4TPkqwBol+hfCOHZ/surDwZDtNv7HA47VrZ45qPUL6J
g+ztGJG1F2D6TR2YLaWKNn+A6TdzUOH7JbFx7zco39zB+WrEjRd936F8C4cz
FkonZ/yGyVs6BBinfHnBCZO3cjjl2mPInAqTt3aY0Lwr8OE3WPzYOExb8Som
+CrMPbYO1xJe+62Rg7nHzkFu2bZn67Jh6u0dLil0PGCIhoWng0P1sjgH47Vf
IPwGB4cvZ6ed6NgJs9/R4ZHk5zXGKb+h8o4OqqJBjre8/0HlnRw+/P9Xx/7+
P1TeyWFRb3e4+k8on8HZIVnqzkwJEaj6BmcHge8eeyqnQc1jcHH4NyNouvsm
qP8aXByKLCWXG6jDws/VIWiN1/NTidD4anB1yOuyu62pBgsPN4egiidlFQt+
QuXdHHg0u99V3IKZ7+6Q8inDYzLXX6i8u4O8c/CMLeehfAYPhzmLfj9ylob5
z8PhRsRWw7LKH1B5T4fm+Tl/l/78uh8AbgEHpA==
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.02, 0.02}], LineBox[CompressedData["
1:eJw1z2tIk1Ecx/G5ZLjS0cXZQF+UrbHSLppaTed+0+mUzDtYbYkVkm9iQhcX
WczoIiWlFi6CzEkIWdnQhDTnEFpT3zSXS2bLdM3ldDXzUhGYFf73wOHwOd9z
DufZfFyVX8pkMBix/8b/eeWblRS6I7JEnXMSWsCB5QqB2jlLDsI3vjaUXecl
rwXXkglP2yQ5FMmvPPXzCXYyDwql8pCr3kGOAOfCroAyxTB5E45ZNSU/ui3k
SOT5mM4ipt98uDS1C0G3e8kCFOs/WaP6B8hCjN2qTBCzTeTtELauX5O91GNc
cTRK2j+OZIW0U9+J3keX7wTU+O/fDTX7YHdOoIEcAzVr69X8jV10Phbya6rT
Xq1//x4I7z5vri5/T47Ds8lSs6zCRo5Hkg0dxj/+/0/AEe7qLrbkA3kvgvtu
yL2nRsn7IPwtcfBe+PfvxzmXc9RXaSWLMJV4vbG85yU5EfdmdIHcqU5yEnI7
tMvhE830XjEYjksPFNtaqCeDEV3gjonLoi6B8/u4uHqpnwzUmkZsLdN9K9YA
SUVVPNWwmboUKevawwoyLNSl8A7+Egzl26mnYMFlbzl8/zP1FJRFYkfT+a/U
U2Fwm8P0q+app0JeXPn0SbiHugxv+RLO44Ev1GWo2dLWf3TuHfU0ZI9VFeYE
DFJPQ5PhZlRd8Wvq6WiwBp/9mTNEPR2aBq7u4YZx6nJcaWWZzrBmqMth5SzK
JnKnqWfgZHxEnvSNj3oG9CG6RdHFSeqZwJJSesI+ZPwLw5fx4Q==
          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotLabel->FormBox["\"Coeff. 3\"", TraditionalForm],
      PlotRange->{{0., 50.}, {-1.534153313637976, 0.0173891645949191}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {967.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->600,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.752724499564453*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
References
\
\>", "Subsubsection",
 CellChangeTimes->{{3.752725290977539*^9, 3.752725299368164*^9}, {
  3.7527253731601562`*^9, 3.7527253790820312`*^9}}],

Cell["\<\
Ludsteck, Johannes (2004), \[OpenCurlyDoubleQuote]VC - An estimator for \
linear (time series and panel) models with time-varying coefficients\
\[CloseCurlyDoubleQuote], \
http://library.wolfram.com/infocenter/MathSource/5195/

Schlicht, Ekkehart (1989), \[CloseCurlyDoubleQuote]Variance Estimation in a \
Random Coefficients Model\[CloseCurlyDoubleQuote], paper presented at the \
Econometric Society European Meeting 1989 in Munich, Germany, \
https://epub.ub.uni-muenchen.de/59143/

Schlicht, Ekkehart and Ludsteck, Johannes (2006), \
\[CloseCurlyDoubleQuote]Variance Estimation in a Random Coefficients Model\
\[CloseCurlyDoubleQuote], Discussion Papers in Economics 904, University of \
Munich, Department of Economics. \
https://ideas.repec.org/p/lmu/muenec/904.html \
\>", "Text",
 CellChangeTimes->{{3.7527253966601562`*^9, 3.7527254975478516`*^9}, {
   3.7527255862978516`*^9, 3.7527256533759766`*^9}, {3.7527257084960938`*^9, 
   3.7527257335585938`*^9}, {3.752725811279297*^9, 3.752725839810547*^9}, {
   3.752725874107422*^9, 3.752725880529297*^9}, 3.7527261623623047`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{721, 659},
WindowMargins->{{257, Automatic}, {Automatic, 118}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb",
PrivateNotebookOptions -> {
 "VersionedStylesheet" -> {"Default.nb"[8.] -> False}}
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 36, 0, 36, "Subsection"],
Cell[618, 24, 2449, 68, 323, "Text"],
Cell[CellGroupData[{
Cell[3092, 96, 47, 0, 27, "Subsubsection"],
Cell[3142, 98, 292, 7, 52, "Input"],
Cell[3437, 107, 146, 3, 29, "Text"],
Cell[3586, 112, 3877, 108, 292, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7500, 225, 94, 2, 27, "Subsubsection"],
Cell[7597, 229, 960, 28, 112, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8594, 262, 85, 1, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[8704, 267, 921, 23, 92, "Input"],
Cell[9628, 292, 4443, 91, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14120, 389, 466, 7, 70, "Subsubsection"],
Cell[CellGroupData[{
Cell[14611, 400, 208, 6, 70, "Input"],
Cell[14822, 408, 125, 3, 70, "Output"]
}, Open  ]],
Cell[14962, 414, 396, 6, 70, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15395, 425, 180, 3, 70, "Subsubsection"],
Cell[CellGroupData[{
Cell[15600, 432, 65, 1, 70, "Input"],
Cell[15668, 435, 353, 8, 70, "Output"]
}, Open  ]],
Cell[16036, 446, 96, 1, 70, "Input"],
Cell[CellGroupData[{
Cell[16157, 451, 301, 6, 70, "Input"],
Cell[16461, 459, 9534, 176, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26044, 641, 163, 5, 70, "Subsubsection"],
Cell[26210, 648, 1095, 20, 70, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

